@@ -13,8 +13,9 @@
 # limitations under the License.
 
 import unittest
-from .card_header import CardHeader
+
 from .card import Card, CardWithId
+from .card_header import CardHeader
 from .section import Section
 from .widgets.text_paragraph import TextParagraph
 
@@ -114,3 +115,27 @@ class CardWithIdTest(unittest.TestCase):
 
     self.assertTrue('card_id' in output)
     self.assertIsNotNone(output['card_id'])
+
+  def test_rename_element(self) -> None:
+    self.maxDiff = None
+    header = CardHeader(title='Princess Bride')
+    section = Section()
+    section.add_widget(TextParagraph(text="Inconceivable!"))
+    card = CardWithId()
+    card.__TAG_OVERRIDE__ = 'pushCard'
+    card.card_id = 'vizzini'
+    card.header = header
+    card.add_section(section)
+    output = card.render()
+
+    self.assertDictEqual(
+        output,
+        {
+            'card_id': 'vizzini',
+            'pushCard': {
+                'header': {'title': 'Princess Bride'},
+                'sections': [{
+                    'widgets': [
+                      {'text_paragraph': {
+                          'text': 'Inconceivable!'
+                      }}]}]}})
